--[[ LibSession

     Check whether a session is new

]]--

local addoninfo, ls = ...
if not Library then Library = {} end
Library.LibSession = ls

local callbacks = {}

local state_known = false
local new_session = nil
local printf = Library.printf.printf

function ls.session_status(callback)
  if state_known then
    local status, value = pcall(callback, new_session)
    if not status then
      printf("LibSession callback failed: %s", value)
    end
    return
  end
  callbacks[#callbacks + 1] = { addon = Inspect.Addon.Current(), callback = callback }
end

local function status_check(event)
  -- try to look up an item from the 1.1 world event
  local status, value = pcall(Inspect.Item.Detail, 'I3D5A8F94699AE819,0A14782951B51E8F,,,,,,')
  if not state_known then
    if status and value then
      new_session = false
    else
      new_session = true
    end
    state_known = true
    for i = 1, #callbacks do
      Utility.Dispatch(function() pcall(callbacks[i].callback, new_session) end, callbacks[i].addon, "LibSession callback notification")
    end
    callbacks = {}
  end
end

-- checking every second should have very low cost -- as long as it
-- hasn't fallen out of the cache, this is a super cheap call every 10
-- seconds
Library.LibCron.recurring(1, status_check)
